| Title: | New Multicriteria Method: AHPGaussian |
|---|---|
| Description: | Implements the Analytic Hierarchy Process (AHP) method using Gaussian normalization (AHPGaussian) to derive the relative weights of the criteria and alternatives. It also includes functions for visualizing the results and generating graphical outputs. Method as described in: dos Santos, Marcos (2021) <doi:10.13033/ijahp.v13i1.833>. |
| Authors: | Cid Edson Povoas [aut, cre] (ORCID: <https://orcid.org/0000-0002-0774-1421>), Marcos dos Santos [aut] (ORCID: <https://orcid.org/0000-0003-1533-5535>) |
| Maintainer: | Cid Edson Povoas <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-05-13 07:34:55 UTC |
| Source: | https://github.com/cidedson/ahpgaussian |
Generic S3 function to apply the AHP-Gaussian method to different input types. Currently implemented for data frames.
ahpgaussian(x)ahpgaussian(x)
x |
Input object (e.g., a data.frame). |
An object of class ahpgaussian.
Apply the AHP-Gaussian method to a data frame.
## Default S3 method: ahpgaussian(x)## Default S3 method: ahpgaussian(x)
x |
A data frame with criteria, alternatives and a column |
An object of class ahpgaussian.
An example data.frame about cellphone model characteristics
data(cellphones)data(cellphones)
The format is:
'data.frame': 5 obs. of 5 variables:
$ criteria: chr "Price" "Camera" "Storage" "Battery Life" ...
$ Xiaomi : int 1500 12 64 24 94
$ Samsung : int 1800 12 128 18 120
$ iPhone : int 5000 20 128 10 117
$ min_max : chr "min" "max" "max" "max" ...
# Description
#
criteria: Statement of the goal, decision criteria and alternatives.
Xiaomi: Xiaomi model;
Samsung: Samsung model; or
iPhone: iPhone model.
min_max: Weights of criteria and alternatives.
data(cellphones) cellphonesdata(cellphones) cellphones
These are methods for objects of class ahpgaussian.
## S3 method for class 'ahpgaussian' plot(x, ...)## S3 method for class 'ahpgaussian' plot(x, ...)
x |
A given object of the class |
... |
Other graphical parameters may also be passed as arguments to these functions. |
Cid Edson Povoas ([email protected])
dos Santos, M, Costa, I. P. de A., & Gomes, C. F. S. (2021) Multicriteria decision-making in the selection of warships: a new approach to the ahp method. International Journal of the Analytic Hierarchy Process, 13(1). <doi:10.13033/ijahp.v13i1.833>
## ## Example 1 ## ahpgaussian ## # ahpgaussian cp <- ahpgaussian(cellphones) plot(cp)## ## Example 1 ## ahpgaussian ## # ahpgaussian cp <- ahpgaussian(cellphones) plot(cp)
Compact print method for summaries of AHP Gaussian results.
## S3 method for class 'summary.ahpgaussian' print(x, ...)## S3 method for class 'summary.ahpgaussian' print(x, ...)
x |
An object of class |
... |
Additional arguments (ignored). |
Returns (and prints) a summary list for ahpgaussian) objects.
## S3 method for class 'ahpgaussian' summary(object, presentation=FALSE, ...)## S3 method for class 'ahpgaussian' summary(object, presentation=FALSE, ...)
object |
A given object of the class |
presentation |
Logic.
If |
... |
Potential further arguments (require by generic). |
Cid Edson Povoas ([email protected])
dos Santos, M, Costa, I. P. de A., & Gomes, C. F. S. (2021) Multicriteria decision-making in the selection of warships: a new approach to the ahp method. International Journal of the Analytic Hierarchy Process, 13(1). <doi:10.13033/ijahp.v13i1.833>
## ## Example 1 ## ahpgaussian ## # ahpgaussian cp <- ahpgaussian(cellphones) summary(cp, TRUE)## ## Example 1 ## ahpgaussian ## # ahpgaussian cp <- ahpgaussian(cellphones) summary(cp, TRUE)
A data.frame Decision Matrix of the data used Santos (2021), the first column lists the criteria, while the next three columns represent the alternatives and the last column represents the objective choice between minimum and maximum for a given criterion. Each model corresponds to an alternative of ship, classified according to its respective criteria.
data(warships)data(warships)
The format is:
'data.frame': 9 obs. of 5 variables:
criteria: chr "Action Radius" "Fuel Endurance" "Autonomy" "Primary Cannon" ...
model_1 : num 4000 11 30 25 1 0 290 592 6
model_2 : num 9330 26 25 25 2 1 310 633 8
model_3 : num 10660 30 35 120 2 ...
min_max : chr "max" "max" "max" "max" ...
#
# Description
#
criteria: Statement of the goal, decision criteria and alternatives.
model_1: Replicate the current Corvette Barroso;
model_2: Build a slightly modernized ship (2.600 ton corvette); or
model_3: Build a model with more significant modernizations (3.000 ton corvette).
min_max: Weights of criteria and alternatives.
dos Santos, M, Costa, I. P. de A., & Gomes, C. F. S. (2021) Multicriteria decision-making in the selection of warships: a new approach to the ahp method. International Journal of the Analytic Hierarchy Process, 13(1). <doi:10.13033/ijahp.v13i1.833>.
data(warships) warshipsdata(warships) warships